OC.L10N.register(
    "notes",
    {
    "Notes" : "筆記",
    "Error" : "錯誤",
    "New note" : "新筆記",
    "Distraction-free notes and writing" : "可以讓你專心記錄不受干擾的筆記應用",
    "Deleted {title}" : "已刪除 {title}",
    "There are unsaved notes. Leaving the page will discard all changes!" : "有未儲存內容。離開頁面會有遺失資料風險。",
    "Settings" : "設定",
    "Folder to store your notes" : "儲存筆記的資料夾",
    "path to notes" : "筆記的路徑",
    "File extension for new notes" : "筆記副檔名",
    "No notes yet" : "尚沒有筆記",
    "All notes" : "全部筆記",
    "Categories" : "分類",
    "Loading …" : "載入中 ...",
    "Today" : "今天",
    "Yesterday" : "昨天",
    "This week" : "本週",
    "Last week" : "上週",
    "This month" : "本月",
    "Last month" : "上月",
    "Rename" : "重新命名",
    "Delete note" : "刪除筆記",
    "Remove from favorites" : "從最愛中移除",
    "Add to favorites" : "新增最愛",
    "Empty note" : "無內容",
    "Write …" : "由此寫入...標題",
    "Details" : "詳細資料",
    "Edit" : "退出",
    "Preview" : "預覽",
    "Exit full screen" : "退出全螢幕",
    "Full screen" : "全螢幕",
    "Save failed. Click to retry." : "儲存失敗。按一下再試。",
    "Set category" : "分類",
    "Category" : "分類",
    "Uncategorized" : "未分類",
    "Click here to save manually" : "手動存檔",
    "Saving failed!" : "儲存失敗",
    "Last modified: {date}" : "上次修改日期：{date}",
    "Note has unsaved changes" : "有未存檔內容",
    "Subcategory" : "子分類",
    "_%n word_::_%n words_" : ["%n 字"],
    "Write down your thoughts without any distractions." : "專心記下你的想法",
    "Use Markdown markups to style your text." : "以標記式語言展現個人排版風格",
    "Organize your notes in categories." : "以不同分類組織筆記",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "可以在手機中安裝應用以便隨時隨地取得筆記",
    "Android app" : "安卓應用",
    "iOS app" : "蘋果應用",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "在導覽列點選 “{newnote}” 開始建立新筆記",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "可以用斜線符號 \"( / )\" 建立子分類。例如；父分類 \"/\"子分類",
    "Updating settings has failed." : "更新設定失敗",
    "Fetching notes has failed." : "取得筆記失敗",
    "Fetching note {id} has failed." : "取得筆記 {id} 失敗",
    "Creating new note has failed." : "新建筆記失敗",
    "Deleting note {id} has failed." : "刪除筆記 {id} 失敗",
    "Toggling favorite for note {id} has failed." : "增/減筆記{id} 到最愛失敗",
    "Updating the note's category has failed. Is the target directory writable?" : "更新筆記的分類失敗。檢查目的地目錄屬性是否為可寫入？",
    "Updating the category for note {id} has failed." : "更新筆記 {id} 的分類失敗"
},
"nplurals=1; plural=0;");
